@@ -10,7 +10,7 @@ import boto3
 
 class LandingZone(ABC):
     @abstractmethod
-    def upload(self, src_path: str, dst_path: str, suffix: str = ""):
+    def upload(self, src_path: str, dst_path: str, suffix: str = "", prefix: str = None):
         pass
 
 
@@ -26,7 +26,7 @@ class FilesystemLandingZone(LandingZone):
         with open(src_path, "rb") as f_in:
             with tempfile.NamedTemporaryFile(
                 "wb",
-                prefix=prefix,
+                prefix=os.path.basename(src_path),
                 delete=False,
                 dir="." + u.path,
                 suffix=suffix,
@@ -39,14 +39,14 @@ class AmazonS3LandingZone(LandingZone):
     def __init__(self):
         self.client = boto3.client("s3")
 
-    def upload(self, src_path: str, dst_path: str, suffix: str = ""):
+    def upload(self, src_path: str, dst_path: str, suffix: str = "", prefix: str = None):
         u = urlparse(dst_path)
 
         if u.scheme != "s3":
             raise RuntimeError("Invalid destination path.")
 
         with open(src_path, "rb") as f_in:
-            f = tempfile.NamedTemporaryFile(delete=False)
+            f = tempfile.NamedTemporaryFile(delete=False, prefix=os.path.basename(src_path))
             final_path = f.name
 
             with gzip.open(f, "wb") as f_out:
